Actions, Resources, and Condition Keys for AWS Certificate Manager Private Certificate Authority - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Certificate Manager Private Certificate Authority.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for AWS Certificate Manager Private Certificate Authority

AWS Certificate Manager Private Certificate Authority (service prefix: `acm-pca`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Certificate Manager Private Certificate Authority
- Resources Defined by AWS Certificate Manager Private Certificate Authority
- Condition Keys for AWS Certificate Manager Private Certificate Authority

## Actions Defined by AWS Certificate Manager Private Certificate Authority

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateCertificateAuthority | Creates an ACM Private CA and its associated private key and configuration. | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateCertificateAuthorityAuditReport | Creates an audit report for an ACM Private CA. | Write | certificate-authority* |  |
CreatePermission | Creates a permission for an ACM Private CA. | Permissions management | certificate-authority* |  |
DeleteCertificateAuthority | Deletes an ACM Private CA and its associated private key and configuration. | Write | certificate-authority* |  |
DeletePermission | Deletes a permission for an ACM Private CA. | Permissions management | certificate-authority* |  |
DescribeCertificateAuthority | Returns a list of the configuration and status fields contained in the specified ACM Private CA. | Read | certificate-authority* |  |
DescribeCertificateAuthorityAuditReport | Returns the status and information about an ACM Private CA audit report. | Read | certificate-authority* |  |
GetCertificate | Retrieves an ACM Private CA certificate and certificate chain for the certificate authority specified by an ARN. | Read | certificate-authority* |  |
GetCertificateAuthorityCertificate | Retrieves an ACM Private CA certificate and certificate chain for the certificate authority specified by an ARN. | Read | certificate-authority* |  |
GetCertificateAuthorityCsr | Retrieves an ACM Private CA certificate signing request (CSR) for the certificate-authority specified by an ARN. | Read | certificate-authority* |  |
ImportCertificateAuthorityCertificate | Imports an SSL/TLS certificate into ACM Private CA for use as the CA certificate of an ACM Private CA. | Write | certificate-authority* |  |
IssueCertificate | Issues an ACM Private CA certificate. | Write | certificate-authority* |  |
| acm-pca:TemplateArn |
ListCertificateAuthorities | Retrieves a list of the ACM Private CA certificate authority ARNs, and a summary of the status of each CA in the calling account. | List |  |  |
ListPermissions | Lists the permissions that have been applied to the ACM Private CA certificate authority. | Read | certificate-authority* |  |
ListTags | Lists the tags that have been applied to the ACM Private CA certificate authority. | Read | certificate-authority* |  |
RestoreCertificateAuthority | Restores an ACM Private CA from the deleted state to the state it was in when deleted. | Write | certificate-authority* |  |
RevokeCertificate | Revokes a certificate issued by an ACM Private CA. | Write | certificate-authority* |  |
TagCertificateAuthority | Adds one or more tags to an ACM Private CA. | Tagging | certificate-authority* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagCertificateAuthority | Remove one or more tags from an ACM Private CA. | Tagging | certificate-authority* |  |
| aws:TagKeys |
UpdateCertificateAuthority | Updates the configuration of an ACM Private CA. | Write | certificate-authority* |  |

## Resources Defined by AWS Certificate Manager Private Certificate Authority

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
certificate-authority | `arn:${Partition}:acm-pca:${Region}:${Account}:certificate-authority/${CertificateAuthorityId}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS Certificate Manager Private Certificate Authority

AWS Certificate Manager Private Certificate Authority defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
acm-pca:TemplateArn | Filters issue certificate requests based on the presence of TemplateArn in the request. | String
aws:RequestTag/${TagKey} | Filters create requests based on the allowed set of values for each of the tags. | String
aws:ResourceTag/${TagKey} | Filters actions based on tag-value associated with the resource. | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request. | String

On this page:

- Actions Defined by AWS Certificate Manager Private Certificate Authority
- Resources Defined by AWS Certificate Manager Private Certificate Authority
- Condition Keys for AWS Certificate Manager Private Certificate Authority

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more